<?php
namespace UmpPayPlantation;
require 'lib/vendor/autoload.php';
use PayMoney\Api\Amount;
use PayMoney\Api\Payer;
use PayMoney\Api\Payment;
use PayMoney\Api\RedirectUrls;
use PayMoney\Api\Transaction;

class PayPlantation extends \Indeed\Ihc\Gateways\PaymentAbstract
{

    protected $paymentType                    = 'ump_payplantation'; // slug. cannot be empty.

    protected $paymentRules                   = [
                'canDoRecurring'						                  => false, // does current payment gateway supports recurring payments.
                'canDoTrial'							                    => false, // does current payment gateway supports trial subscription
                'canDoTrialFree'						                  => false, // does current payment gateway supports free trial subscription
                'canApplyCouponOnRecurringForFirstPayment'		=> false, // if current payment gateway support coupons on recurring payments only for the first transaction
                'canApplyCouponOnRecurringForFirstFreePayment'=> false, // if current payment gateway support coupons with 100% discount on recurring payments only for the first transaction.
                'canApplyCouponOnRecurringForEveryPayment'	  => true, // if current payment gateway support coupons on recurring payments for every transaction
                'paymentMetaSlug'                             => 'ump_payplantation', // payment gateway slug. exenple: paypal, stripe, etc.
                'returnUrlAfterPaymentOptionName'             => 'ump_payplantation-return_page', // option name ( in wp_option table ) where it's stored the return URL after a payment is done.
                'returnUrlOnCancelPaymentOptionName'          => '', // option name ( in wp_option table ) where it's stored the return URL after a payment is canceled.
                'paymentGatewayLanguageCodeOptionName'        => '', // option name ( in wp_option table ) where it's stored the language code.
    ]; // some payment does not support all our features
    protected $intervalSubscriptionRules      = [
                'daysSymbol'               => '',
                'weeksSymbol'              => '',
                'monthsSymbol'             => 'Monthly',
                'yearsSymbol'              => 'Annual',
                'daysSupport'              => false,
                'daysMinLimit'             => 7,
                'daysMaxLimit'             => 90,
                'weeksSupport'             => false,
                'weeksMinLimit'            => 1,
                'weeksMaxLimit'            => 52,
                'monthsSupport'            => true,
                'monthsMinLimit'           => 1,
                'monthsMaxLimit'           => 6,
                'yearsSupport'             => true,
                'yearsMinLimit'            => 1,
                'yearsMaxLimit'            => 15,
                'maximumRecurrenceLimit'   => 52, // leave this empty for unlimited
                'minimumRecurrenceLimit'   => 2,
                'forceMaximumRecurrenceLimit'   => false,
    ];
    protected $intervalTrialRules             = [
                              'daysSymbol'               => '',
                              'weeksSymbol'              => '',
                              'monthsSymbol'             => '',
                              'yearsSymbol'              => '',
                              'supportCertainPeriod'     => false,
                              'supportCycles'            => false,
                              'cyclesMinLimit'           => 1,
                              'cyclesMaxLimit'           => '',
                              'daysSupport'              => false,
                              'daysMinLimit'             => 1,
                              'daysMaxLimit'             => 90,
                              'weeksSupport'             => false,
                              'weeksMinLimit'            => 1,
                              'weeksMaxLimit'            => 52,
                              'monthsSupport'            => true,
                              'monthsMinLimit'           => 1,
                              'monthsMaxLimit'           => 24,
                              'yearsSupport'             => false,
                              'yearsMinLimit'            => 1,
                              'yearsMaxLimit'            => 5,
    ];

    protected $stopProcess                    = false;
    protected $inputData                      = []; // input data from user
    protected $paymentOutputData              = [];
    protected $paymentSettings                = []; // api key, some credentials used in different payment types

    protected $paymentTypeLabel               = 'PayPlantation'; // label of payment
    protected $redirectUrl                    = ''; 
    protected $defaultRedirect                = ''; // redirect home
    protected $errors                         = [];

    /**
     * @param none
     * @return object
     */
    public function charge()
    { 

     	$client_id = $this->paymentSettings['ump_payplantation-merchant_id'];
		$client_secret =  $this->paymentSettings['ump_payplantation-merchant_key'];


		if ( $client_id === false || $client_id === '' || $client_secret === false || $client_secret === '' ){
			return $this;
		}

        $order_id = $this->paymentOutputData['order_id'];
		$notify_url =  get_site_url() . '/?ihc_action=ump_payplantation&order_id=' . $order_id . '&token=';

		$amountOrder = $this->paymentOutputData['amount'] ;
		$currency = $this->paymentOutputData['currency'];
        

        if ( empty( $order_id ) || empty( $amountOrder ) || empty( $currency ) ){
            return $this;
        }
        
        $returnUrl = get_option( 'ump_payplantation-return_page', 0 );
  
		if ( $returnUrl > 0 ){
			$returnUrl = get_permalink( $returnUrl );
		}
		if ( $returnUrl == 0 || $returnUrl == false || $returnUrl == '' || $returnUrl == '-1' ){
		    $returnUrl = get_site_url();
		}


		$payer = new Payer();
		$payer->setPaymentMethod('Payplantation'); 

		//Amount Object
		$amount = new Amount();
		$amount->setTotal($amountOrder)->setCurrency($currency);

		//Transaction Object
		$trans = new Transaction();
		$trans->setAmount($amount);

		//RedirectUrls Object
		$urls = new RedirectUrls();
		$urls->setSuccessUrl($notify_url) 

		->setCancelUrl($notify_url);
		//Payment Object
		$payment = new Payment();
		$payment->setCredentials([ 
			'client_id' => $client_id,
			'client_secret' => $client_secret, 
		])
		->setRedirectUrls($urls)
		->setPayer($payer)
		->setTransaction($trans);

		try {
			$payment->create();
	    	$redirect_url = $payment->getApprovedUrl();
	    	 
		} catch (\Exception $ex) {

			$redirect_url = $returnUrl;
	        
		}
		
        $this->redirectUrl = $redirect_url;
        return $this;
    }

    /**
     * @param none
     * @return none
     */
    public function webhook()
    {			
 
    	if (isset($_GET['order_id']) && isset($_GET['token']) && !empty( $_GET['token'] ) && !empty( $_GET['order_id'] )  ) {
             $order_id = filter_var($_GET['order_id'], FILTER_SANITIZE_NUMBER_INT);
			 $orderObject = new \Indeed\Ihc\Db\Orders();
             $orderData = $orderObject->setId($order_id)
                                       ->fetch()
                                       ->get();
			$encoded = wp_json_encode(filter_var($_GET['token'], FILTER_SANITIZE_STRING));
			$encoded = substr($encoded, 1);
			$decoded = json_decode(base64_decode($encoded), true);

			if (200 === $decoded['status']) {
				$transactionId = $decoded['transaction_id'];
                 
    			$status = 'completed';
                $this->webhookData = [
                                          'transaction_id'              => $transactionId,
                                          'uid'                         => isset( $orderData->uid ) ? $orderData->uid : 0,
                                          'lid'                         => isset( $orderData->lid ) ? $orderData->lid : 0,
                                          'order_identificator'         => $transactionId,
                                          'amount'                      => $orderData->amount_value,
                                          'currency'                    => $orderData->amount_type,
                                          'payment_details'             => $status,
                                          'payment_status'              => $status,
              ];
			} 
			$returnUrl = get_site_url().'/thank-you-page';
		}else{
		    $returnUrl = get_site_url().'/Subscription-Plan';
		}

        echo '<script> const targetURL = "'.$returnUrl.'"; window.location.href = targetURL;
              </script>';
         
    }

    /**
     * @param int
     * @param int
     * @param string
     * @return none
     */
    public function canDoCancel( $uid=0, $lid=0, $subscriptionId='' )
    {
 
    }


    /**
     * @param int
     * @param int
     * @param string
     * @return none
     */
    public function cancel( $uid=0, $lid=0, $transactionId='' )
    {

    }


}
